@@ -10,8 +10,8 @@ details. */
    the Cygwin shared library".  This version is used to track important
    changes to the DLL and is mainly informative in nature. */
 
-#define CYGWIN_VERSION_DLL_MAJOR 2006
-#define CYGWIN_VERSION_DLL_MINOR 0
+#define CYGWIN_VERSION_DLL_MAJOR 2008
+#define CYGWIN_VERSION_DLL_MINOR 2
 
 /* Major numbers before CYGWIN_VERSION_DLL_EPOCH are incompatible. */
 
@@ -469,12 +469,21 @@ details. */
   302: Export nl_langinfo_l.
   303: Export pthread_getname_np, pthread_setname_np.
   304: Export strerror_l, strptime_l, wcsftime_l.
+  305: [f]pathconf flag _PC_CASE_INSENSITIVE added.
+  306: Export getentropy, getrandom.
+  307: Export timingsafe_bcmp, timingsafe_memcmp.
+  308: Export dladdr.
+  309: Export getloadavg.
+  310: Export reallocarray.
+  311: Export __xpg_sigpause.
+  312: Export strverscmp, versionsort.
+  313: Export fls, flsl, flsll.
 
   Note that we forgot to bump the api for ualarm, strtoll, strtoull,
   sigaltstack, sethostname. */
 
 #define CYGWIN_VERSION_API_MAJOR 0
-#define CYGWIN_VERSION_API_MINOR 304
+#define CYGWIN_VERSION_API_MINOR 313
 
 /* There is also a compatibity version number associated with the shared memory
    regions.  It is incremented when incompatible changes are made to the shared
